==> distribution-6.0.0-dev.128.zip: drr/standards/iosco/upi/validation/exists/AnnaDsbRateGroupOnlyExistsValidator.java <==
package drr.standards.iosco.upi.validation.exists;

import com.google.common.collect.ImmutableMap;
import com.rosetta.model.lib.path.RosettaPath;
import com.rosetta.model.lib.validation.ExistenceChecker;
import com.rosetta.model.lib.validation.ValidationResult;
import com.rosetta.model.lib.validation.ValidationResult.ValidationType;
import com.rosetta.model.lib.validation.ValidatorWithArg;
import drr.standards.iosco.upi.AnnaDsbRateDetail;
import drr.standards.iosco.upi.AnnaDsbRateGroup;
import java.util.Map;
import java.util.Set;
import java.util.stream.Collectors;

import static com.rosetta.model.lib.validation.ValidationResult.failure;
import static com.rosetta.model.lib.validation.ValidationResult.success;

public class AnnaDsbRateGroupOnlyExistsValidator implements ValidatorWithArg<AnnaDsbRateGroup, Set<String>> {

	/* Casting is required to ensure types are output to ensure recompilation in Rosetta */
	@Override
	public <T2 extends AnnaDsbRateGroup> ValidationResult<AnnaDsbRateGroup> validate(RosettaPath path, T2 o, Set<String> fields) {
		Map<String, Boolean> fieldExistenceMap = ImmutableMap.<String, Boolean>builder()
				.put("Rates", ExistenceChecker.isSet((AnnaDsbRateDetail) o.getRates()))
				.build();
		
		// Find the fields that are set
		Set<String> setFields = fieldExistenceMap.entrySet().stream()
				.filter(Map.Entry::getValue)
				.map(Map.Entry::getKey)
				.collect(Collectors.toSet());
		
		if (setFields.equals(fields)) {
			return success("AnnaDsbRateGroup", ValidationType.ONLY_EXISTS, "AnnaDsbRateGroup", path, "");
		}
		return failure("AnnaDsbRateGroup", ValidationType.ONLY_EXISTS, "AnnaDsbRateGroup", path, "",
				String.format("[%s] should only be set.  Set fields: %s", fields, setFields));
	}
}

==> distribution-6.25.3.zip: drr/standards/iosco/upi/validation/exists/AnnaDsbRateGroupOnlyExistsValidator.java <==
package drr.standards.iosco.upi.validation.exists;

import com.google.common.collect.ImmutableMap;
import com.rosetta.model.lib.path.RosettaPath;
import com.rosetta.model.lib.validation.ExistenceChecker;
import com.rosetta.model.lib.validation.ValidationResult;
import com.rosetta.model.lib.validation.ValidatorWithArg;
import drr.standards.iosco.upi.AnnaDsbRateDetail;
import drr.standards.iosco.upi.AnnaDsbRateGroup;
import java.util.Map;
import java.util.Set;
import java.util.stream.Collectors;

import static com.rosetta.model.lib.validation.ValidationResult.failure;
import static com.rosetta.model.lib.validation.ValidationResult.success;

public class AnnaDsbRateGroupOnlyExistsValidator implements ValidatorWithArg<AnnaDsbRateGroup, Set<String>> {

	/* Casting is required to ensure types are output to ensure recompilation in Rosetta */
	@Override
	public <T2 extends AnnaDsbRateGroup> ValidationResult<AnnaDsbRateGroup> validate(RosettaPath path, T2 o, Set<String> fields) {
		Map<String, Boolean> fieldExistenceMap = ImmutableMap.<String, Boolean>builder()
				.put("Rates", ExistenceChecker.isSet((AnnaDsbRateDetail) o.getRates()))
				.build();
		
		// Find the fields that are set
		Set<String> setFields = fieldExistenceMap.entrySet().stream()
				.filter(Map.Entry::getValue)
				.map(Map.Entry::getKey)
				.collect(Collectors.toSet());
		
		if (setFields.equals(fields)) {
			return success("AnnaDsbRateGroup", ValidationResult.ValidationType.ONLY_EXISTS, "AnnaDsbRateGroup", path, "");
		}
		return failure("AnnaDsbRateGroup", ValidationResult.ValidationType.ONLY_EXISTS, "AnnaDsbRateGroup", path, "",
				String.format("[%s] should only be set.  Set fields: %s", fields, setFields));
	}
}
